@@ -1,4 +1,4 @@
-`disc.1r` <-
+disc.1r <-
 function (data, convar, binsize = 6)
 {
 #*************************************************
