@@ -1,4 +1,4 @@
-`disc.ef` <-
+disc.ef <-
 function(data, varcon,k)
 {
 #****************************************************
