@@ -1,4 +1,4 @@
-`distancia` <-
+distancia <-
 function(x, y)
 {
 #****************************************************
