@@ -1,4 +1,4 @@
-`inconsist` <-
+inconsist <-
 function(data)
 {
 #*******************************************************************
