@@ -1,4 +1,4 @@
-`lvf` <-
+lvf <-
 function(data, lambda, maxiter)
 {
 #*****************************************
