@@ -1,4 +1,4 @@
-`mo4` <-
+mo4 <-
 function(data) 
 {
 #*****************************************
