@@ -1,4 +1,4 @@
-`relief` <-
+relief <-
 function (data,nosample,threshold,vnom=0) 
 {if(vnom[1]>0)
 {reliefcat(data,nosample,threshold,vnom)}
