@@ -1,4 +1,4 @@
-`sfs` <-
+sfs <-
 function(data,method=c("lda","knn","rpart"),kvec=5,repet=10)
 {
 # *******************************************************
